@@ -46,14 +46,10 @@
 #' @examples
 #' \dontrun{
 #' file <- system.file('extdata', 'firesting_file.txt', package = 'respirometry')
-#' import_witrox(file, o2_unit = 'umol_per_l')
-#' 
-#' # Oops. I forgot to change the salinity value when I calibrated
-#' # the instrument. Override the values in the file for 35 psu.
-#' import_witrox(file, o2_unit = 'umol_per_kg', overwrite_sal = 35)
+#' import_firesting(file, o2_unit = 'umol_per_l')
 #' 
 #' # I want each channel as a separate data frame.
-#' data_list <- import_witrox(file, split_channels = TRUE)
+#' data_list <- import_firesting(file, split_channels = TRUE)
 #' data_list$CH_3 # here's the channel 3 data frame.
 #' }
 #'
@@ -63,7 +59,7 @@
 import_firesting = function(file, o2_unit = 'percent_a.s.', date = '%m/%d/%Y %X', overwrite_sal = NULL, keep_metadata = FALSE, drop_channels = TRUE, split_channels = FALSE){
 	raw = readChar(file, nchars = file.info(file)$size, useBytes = TRUE)
 	raw = gsub(pattern = '\xb0|\xa9|\xfc\xbe\x8e\x93\xa0\xbc', replacement = ' ', raw) # replace non ASCII characters
-	raw = strsplit(raw, split = '\r\n', fixed = T)[[1]]
+	raw = strsplit(raw, split = '\r+\n')[[1]]
 	raw = raw[sapply(raw, nchar) > 0] # remove blank rows
 	f = strsplit(raw, split = '\t', fixed = TRUE)
 	sals = as.numeric(sapply(f[grep('Settings:', f[1:50]) + 1:4], '[', grep('Salinity', f[[grep('Settings:', f[1:50])]])))
